import 'dart:typed_data';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_inappwebview_forked/flutter_inappwebview.dart';

import 'main.dart';

class HeadlessInAppWebViewExampleScreen extends StatefulWidget {
  @override
  _HeadlessInAppWebViewExampleScreenState createState() =>
      new _HeadlessInAppWebViewExampleScreenState();
}

class _HeadlessInAppWebViewExampleScreenState
    extends State<HeadlessInAppWebViewExampleScreen> {
  HeadlessInAppWebView? headlessWebView1;
  HeadlessInAppWebView? headlessWebView2;
  String url = "";

  Uint8List? _screenshot1 = Uint8List(0);
  Uint8List? _screenshot2 = Uint8List(0);

  @override
  void initState() {
    super.initState();

    headlessWebView1 = new HeadlessInAppWebView(
      initialUrlRequest: URLRequest(url: Uri.parse("https://flutter.dev")),
      onWebViewCreated: (controller) {
        print('HeadlessInAppWebView1 created!');
      },
    );

    headlessWebView2 = new HeadlessInAppWebView(
        initialUrlRequest: URLRequest(url: Uri.parse("https://imvictor.me")),
        onWebViewCreated: (controller) {
          print('HeadlessInAppWebView2 created!');
        });
  }

  @override
  void dispose() {
    super.dispose();
    headlessWebView1?.dispose();
    headlessWebView2?.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
            title: Text(
              "HeadlessInAppWebView",
            )),
        drawer: myDrawer(context: context),
        body: SingleChildScrollView(
            child: Column(children: <Widget>[
          Container(
            padding: EdgeInsets.all(20.0),
            child: Text(
                "CURRENT URL\n${(url.length > 50) ? url.substring(0, 50) + "..." : url}"),
          ),
          Center(
            child: ElevatedButton(
                onPressed: () async {
                  await headlessWebView1?.dispose();
                  await headlessWebView1?.run();
                },
                child: Text("Run HeadlessInAppWebView1")),
          ),
          Center(
            child: ElevatedButton(
                onPressed: () async {
                  await headlessWebView2?.dispose();
                  await headlessWebView2?.run();
                },
                child: Text("Run HeadlessInAppWebView2")),
          ),
          Center(
            child: ElevatedButton(
                onPressed: () async {
                  try {
                    await headlessWebView1?.webViewController
                        .evaluateJavascript(
                            source: """console.log('Here is the message!');""");
                  } on MissingPluginException {
                    print(
                        "HeadlessInAppWebView is not running. Click on \"Run HeadlessInAppWebView\"!");
                  }
                },
                child: Text("Send console.log message")),
          ),
          Center(
            child: ElevatedButton(
              onPressed: () async {
                var screenshot = await headlessWebView1?.webViewController.takeScreenshot(
                  screenshotConfiguration: ScreenshotConfiguration(

                  )
                );
                setState(() {
                  _screenshot1 = screenshot;
                });
              },
              child: Text("Capture HeadlessInAppWebView1"),
            ),
          ),
          Center(
            child: ElevatedButton(
              onPressed: () async {
                var screenshot = await headlessWebView2?.capture();
                setState(() {
                  _screenshot2 = screenshot;
                });
              },
              child: Text("Capture HeadlessInAppWebView2"),
            ),
          ),
          Center(
            child: ElevatedButton(
                onPressed: () {
                  headlessWebView1?.dispose();
                },
                child: Text("Dispose HeadlessInAppWebView1")),
          ),
          Center(
            child: ElevatedButton(
                onPressed: () {
                  headlessWebView2?.dispose();
                },
                child: Text("Dispose HeadlessInAppWebView2")),
          ),
          Center(
              child: _screenshot1!.length > 0
                  ? Image.memory(_screenshot1!)
                  : Text("Capture 1")),
          Center(
              child: _screenshot2!.length > 0
                  ? Image.memory(_screenshot2!)
                  : Text("Capture 2"))
        ])));
  }
}
